"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Provider = void 0;
var _react = _interopRequireDefault(require("react"));
var _ChatComponent = require("./ChatComponent");
var _constants = require("./constants");
var _entities = require("./entities");
var _SessionStorageGateway = require("./gateways/SessionStorageGateway");
var _MessageHttpSocketGateway = require("./gateways/MessageHttpSocketGateway");
var _adapters = require("./infra/adapters");
var _EncryptedStorageAdapter = require("./infra/adapters/EncryptedStorageAdapter");
var _utils = require("./utils");
var _global = require("./global");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// import { NotificationRnGateway } from './gateways/NotificationRnGateway';

// import { NotificationAdapter } from './infra/adapters/NotificationAdapter';

const Provider = props => {
  _global.Global.botId = props.botId;
  _global.Global.params = props.params;
  const env = (0, _utils.getEnvironment)(props.staging);
  const configurations = new _entities.ChatConfigurations(_constants.initialConfigs.title, _constants.initialConfigs.poweredBy, _constants.initialConfigs.poweredByUrl, _constants.initialConfigs.settings);
  const logger = new _adapters.ConsoleLoggerAdapter();
  const wsAdapter = new _adapters.WebSocketAdapter(env.SOCKET_URL, logger);
  const httpClient = new _adapters.AxiosHttpConnectionAdapter(env.API_URL, logger);
  const storage = new _EncryptedStorageAdapter.EncryptedStorageAdapter();
  const session = new _SessionStorageGateway.SessionStorageGateway(storage, httpClient, wsAdapter);

  // const notificationAdapter = new NotificationAdapter();

  // const notificationGateway = new NotificationRnGateway(notificationAdapter);

  const messageGateway = new _MessageHttpSocketGateway.MessageHttpSocketGateway(wsAdapter, httpClient, storage, session);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_ChatComponent.ChatComponent, {
    sessionGateway: session,
    messagesGateway: messageGateway,
    configurations: configurations
    // notificationGateway={notificationGateway}
    ,
    ws: wsAdapter
  }));
};
exports.Provider = Provider;
//# sourceMappingURL=Provider.js.map