"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getMessageType = exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _reactNativeDocumentPicker = _interopRequireDefault(require("react-native-document-picker"));
var _utils = require("../../../../../../utils");
var _types = require("../../../../../../types");
var _styles = require("./styles");
var _attach_icon = _interopRequireDefault(require("../../../../../../assets/attach_icon.png"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const getMessageType = type => {
  switch (type) {
    case 'application':
    case 'msword':
    case 'text':
      return _types.MessageTypes.DOCUMENT;
    case 'video':
      return _types.MessageTypes.VIDEO;
    case 'image':
      return _types.MessageTypes.IMAGE;
    default:
      return _types.MessageTypes.IMAGE;
  }
};
exports.getMessageType = getMessageType;
const FilePicker = _ref => {
  let {
    sendMessage
  } = _ref;
  const handleSubmitMessage = msg => {
    sendMessage(msg);
  };
  const handleDocumentSelection = async () => {
    try {
      const response = await _reactNativeDocumentPicker.default.pick({
        presentationStyle: 'fullScreen',
        allowMultiSelection: true
      });
      if (response) {
        await Promise.all(response.map(async file => {
          var _file$type;
          const [type, ext] = file === null || file === void 0 ? void 0 : (_file$type = file.type) === null || _file$type === void 0 ? void 0 : _file$type.split('/');
          const messageType = getMessageType(type);
          const base64String = await (0, _utils.toBase64)(file === null || file === void 0 ? void 0 : file.uri);
          const msg = {
            ext,
            from: _types.From.USER,
            isMedia: true,
            type: messageType,
            message: `data:${file === null || file === void 0 ? void 0 : file.type};base64,${base64String}`,
            localFileUri: file === null || file === void 0 ? void 0 : file.uri
          };
          if ([_types.MessageTypes.DOCUMENT, _types.MessageTypes.VIDEO].includes(messageType)) {
            msg.document = {
              fileUrl: file === null || file === void 0 ? void 0 : file.uri,
              size: file === null || file === void 0 ? void 0 : file.size,
              title: file === null || file === void 0 ? void 0 : file.name
            };
          }
          return handleSubmitMessage(msg);
        }));
      }
    } catch (err) {
      if (_reactNativeDocumentPicker.default.isCancel(err)) return;
      throw err;
    }
  };
  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    testID: "filePicker",
    onPress: handleDocumentSelection
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
    source: _attach_icon.default,
    style: _styles.styles.attachIcon
  }));
};
var _default = FilePicker;
exports.default = _default;
//# sourceMappingURL=index.js.map