"use strict";

var _react = _interopRequireDefault(require("react"));
var _reactNative = require("@testing-library/react-native");
var _ = _interopRequireWildcard(require("."));
var _types = require("../../../../../../types");
var _reactNativeDocumentPicker = _interopRequireDefault(require("react-native-document-picker"));
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
jest.mock('react-native-document-picker');
jest.mock('../../../../../../utils/toBase64');
jest.mock('react-native-fs', () => ({
  readFile: jest.fn()
}));
describe('FilePicker', () => {
  const sendMessage = jest.fn();
  afterEach(() => jest.clearAllMocks());
  it('calls DocumentPicker.pick when filePicker is pressed', async () => {
    const pickSpy = jest.spyOn(_reactNativeDocumentPicker.default, 'pick');
    const {
      getByTestId
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, {
      sendMessage: sendMessage
    }));
    const filePicker = getByTestId('filePicker');
    _reactNative.fireEvent.press(filePicker);
    expect(pickSpy).toHaveBeenCalled();
  });
  it('handles document selection correctly and adds message', async () => {
    const mockResponse = [{
      uri: 'file1_uri',
      type: 'application/pdf',
      name: 'file1.pdf',
      size: 1234,
      message: 'data:application/pdf;base64,undefined'
    }, {
      uri: 'file2_uri',
      name: 'file2.jpg',
      size: 5678,
      type: 'image/jpeg',
      localFileUri: 'file2.jpg',
      message: 'data:image/jpeg;base64,undefined'
    }];
    _reactNativeDocumentPicker.default.pick.mockResolvedValue(mockResponse);
    const {
      getByTestId
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, {
      sendMessage: sendMessage
    }));
    const filePicker = getByTestId('filePicker');
    await _reactNative.fireEvent.press(filePicker);
    const expectedMessages = mockResponse.map(file => {
      const [type, ext] = file.type.split('/');
      const messageType = (0, _.getMessageType)(type);
      const expectedMsg = {
        id: undefined,
        ext,
        from: _types.From.USER,
        isMedia: true,
        type: messageType,
        message: file.message,
        localFileUri: file.uri
      };
      if (messageType === _types.MessageTypes.DOCUMENT || messageType === _types.MessageTypes.VIDEO) {
        expectedMsg.document = {
          fileUrl: file.uri,
          size: file.size,
          title: file.name
        };
      }
      return expectedMsg;
    });
    expect(sendMessage).toHaveBeenCalledWith(expectedMessages[0]);
    expect(sendMessage).toHaveBeenCalledWith(expectedMessages[1]);
    expect(_reactNativeDocumentPicker.default.pick).toHaveBeenCalled();
    expect(sendMessage).toHaveBeenCalledTimes(mockResponse.length);
  });
  it('does not add a message when document picker is canceled', async () => {
    _reactNativeDocumentPicker.default.isCancel.mockReturnValue(true);
    const {
      getByTestId
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, {
      sendMessage: sendMessage
    }));
    const filePicker = getByTestId('filePicker');
    _reactNative.fireEvent.press(filePicker);
    expect(sendMessage).not.toHaveBeenCalled();
  });
});
//# sourceMappingURL=index.spec.js.map