"use strict";

var _react = _interopRequireDefault(require("react"));
var _reactNative = require("@testing-library/react-native");
var _ = require(".");
var _types = require("../../../../types");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
jest.mock('react-native-fs', () => ({
  readFile: jest.fn()
}));
describe('Input', () => {
  it('renders input field with correct placeholder', () => {
    const {
      getByPlaceholderText
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.Input, {
      sendMessage: () => {}
    }));
    const inputField = getByPlaceholderText('Digite algo ...');
    expect(inputField).toBeTruthy();
  });
  it('calls addMessage when send button is pressed', () => {
    const sendMessage = jest.fn();
    const expectedMessage = 'Hello, world!';
    const {
      getByTestId
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.Input, {
      sendMessage: sendMessage
    }));
    const sendButton = getByTestId('sendIcon');
    const inputField = getByTestId('messageInput');
    _reactNative.fireEvent.changeText(inputField, expectedMessage);
    _reactNative.fireEvent.press(sendButton);
    const expectedMsgObject = {
      message: expectedMessage,
      id: undefined,
      from: _types.From.USER,
      type: _types.MessageTypes.TEXT
    };
    expect(sendMessage).toHaveBeenCalledWith(expectedMsgObject);
    expect(inputField.props.value).toBe('');
  });
  it('does not send empty messages', () => {
    const sendMessage = jest.fn();
    const {
      getByTestId
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.Input, {
      sendMessage: sendMessage
    }));
    const sendIconElement = getByTestId('sendIcon');
    _reactNative.fireEvent.press(sendIconElement);
    expect(sendMessage).not.toHaveBeenCalled();
  });
  it('handles user input correctly', () => {
    const {
      getByTestId
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.Input, {
      sendMessage: () => {}
    }));
    const inputElement = getByTestId('messageInput');
    const expectedMessage = 'test message';
    _reactNative.fireEvent.changeText(inputElement, expectedMessage);
    expect(inputElement.props.value).toBe(expectedMessage);
  });
});
//# sourceMappingURL=index.spec.js.map