"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MessageHttpSocketGateway = void 0;
var _types = require("../types");
var _MessageList = require("../entities/MessageList");
var _constants = require("../constants");
var _global = require("../global");
class MessageHttpSocketGateway {
  constructor(ws, httpConnection, storage, sessionGateway) {
    this.ws = ws;
    this.httpConnection = httpConnection;
    this.storage = storage;
    this.sessionGateway = sessionGateway;
  }
  async sendStatus(messageId, status) {
    const sessionId = await this.sessionGateway.getCurrent();
    const payload = {
      sessionId,
      botId: _global.Global.botId,
      status,
      messageId
    };
    await this.httpConnection.post('/webchat/status', payload);
  }
  async getMessages() {
    const messages = await this.storage.retrieve('messages');
    if (typeof messages === 'object') {
      return new _MessageList.MessageList(messages);
    }
    return new _MessageList.MessageList([]);
  }
  async sendMessage(msg) {
    const messages = await this.storage.retrieve('messages');
    if (messages && typeof messages === 'object') {
      messages.push(msg);
      await this.storage.store('messages', JSON.stringify(messages));
      const sessionId = await this.storage.retrieve('sessionId');
      if (!sessionId) {
        await this.sessionGateway.subscribe('');
      } else {
        await this.httpConnection.post('/webchat/message', {
          botId: _global.Global.botId,
          message: msg.message,
          isMedia: msg.type !== _types.MessageTypes.TEXT,
          ext: msg.ext,
          sessionId: sessionId,
          botChannel: _constants.channel,
          isPreview: false,
          socketId: _global.Global.socketId
        });
      }
      return new _MessageList.MessageList(messages);
    }
  }
  async storeMessage(msg) {
    const stored = await this.storage.retrieve('messages');
    if (typeof stored === 'object') {
      stored.push(msg);
      await this.storage.store('messages', JSON.stringify(stored));
      return new _MessageList.MessageList(stored);
    } else {
      const messageList = [msg];
      await this.storage.store('messages', JSON.stringify(messageList));
      return new _MessageList.MessageList(messageList);
    }
  }
  clearMessages() {
    return Promise.resolve(new _MessageList.MessageList([]));
  }
  onMessage(callback) {
    this.ws.onMessage(callback);
  }
}
exports.MessageHttpSocketGateway = MessageHttpSocketGateway;
//# sourceMappingURL=MessageHttpSocketGateway.js.map