import React, { useState, useRef, useEffect } from 'react';
// import { AppState } from 'react-native';

import { Widget } from './components/Widget';
import { Chat } from './components/Chat';
import { ChatConfigurations, MessageList, Observer } from './entities';

// import type { NotificationGateway } from './gateways/NotificationGateway';

import { From, MessageTypes } from './types';
export const ChatComponent = _ref => {
  let {
    configurations,
    ws,
    sessionGateway,
    messagesGateway
  } = _ref;
  // const [isAppOpened, setIsAppOpened] = useState(false);

  // AppState.addEventListener('change', (state) => {
  //   setIsAppOpened(state === 'active');
  // });

  const [sessionState, setSessionState] = useState(null);
  const [messageState, setMessageState] = useState(new MessageList([]));
  const wsRef = useRef(null);
  const onIncomingMessage = (data, from) => {
    const newMessageList = new MessageList(messageState === null || messageState === void 0 ? void 0 : messageState.messages);
    newMessageList.observers = (messageState === null || messageState === void 0 ? void 0 : messageState.observers) || [];
    newMessageList.addMessage({
      ...data,
      id: data.id || `${Date.now() * Math.random()}`,
      from
    });
    setMessageState(newMessageList);

    // const hasToNotify =
    //   data.type !== MessageTypes.TYPING && from === From.BOT && !isAppOpened;

    // if (hasToNotify) {
    //   notificationGateway.postLocal(data.message);
    // }
  };

  sessionGateway.onEndConversation(async () => {
    await sessionGateway.clearSession();
  });
  messagesGateway.onMessage(msg => onIncomingMessage(msg, From.BOT));
  useEffect(() => {
    if (!wsRef.current) {
      wsRef.current = ws;
      wsRef.current.connect();
      wsRef.current.onOpen(async () => {
        await sessionGateway.linkSession();
      });
    }
  }, [ws, sessionGateway]);
  useEffect(() => {
    async function loadData() {
      const [storedSession, storedMessages] = await Promise.all([sessionGateway.getCurrent(), messagesGateway.getMessages()]);
      storedSession.register(new Observer('sendAction', async data => {
        await sessionGateway.sendAction(data);
      }));
      storedSession.register(new Observer('clearSession', async () => {
        await sessionGateway.clearSession();
        const newSession = await sessionGateway.subscribe('');
        newSession.observers = storedSession.observers;
        setSessionState(newSession);
      }));
      await sessionGateway.subscribe(storedSession.current);
      setSessionState(storedSession);
      storedMessages.register(new Observer('addMessage', async data => {
        if (data.type !== MessageTypes.TYPING) {
          if (data.from === From.USER) {
            await messagesGateway.sendMessage(data);
          } else {
            await messagesGateway.sendStatus(data.id, 'delivered');
            await messagesGateway.storeMessage(data);
          }
        }
      }));
      setMessageState(storedMessages);
    }
    loadData();
  }, [sessionGateway, messagesGateway]);
  const restartConversation = () => {
    const messageList = new MessageList([]);
    messageList.observers = (messageState === null || messageState === void 0 ? void 0 : messageState.observers) || [];
    setMessageState(messageList);
    messageState === null || messageState === void 0 ? void 0 : messageState.clearMessages();
    sessionState === null || sessionState === void 0 ? void 0 : sessionState.clearSession();
  };
  const [configurationsState, setConfigurationsState] = useState(new ChatConfigurations(configurations.title, configurations.poweredBy, configurations.poweredBy, configurations.settings, configurations.isOpen));
  const toggleIsChatOpen = () => {
    const updatedConfigurations = new ChatConfigurations(configurationsState.title, configurationsState.poweredBy, configurationsState.poweredByUrl, configurationsState.settings, configurationsState.isOpen);
    updatedConfigurations.toggleIsOpen();
    setConfigurationsState(updatedConfigurations);
  };
  const closeChat = () => {
    const updatedConfigurations = new ChatConfigurations(configurationsState.title, configurationsState.poweredBy, configurationsState.poweredByUrl, configurationsState.settings, configurationsState.isOpen);
    updatedConfigurations.close();
    setConfigurationsState(updatedConfigurations);
  };
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Chat, {
    messages: (messageState === null || messageState === void 0 ? void 0 : messageState.messages) || [],
    configurations: configurationsState,
    close: closeChat,
    restartConversation: restartConversation,
    sendMessage: msg => onIncomingMessage(msg, From.USER)
  }), /*#__PURE__*/React.createElement(Widget, {
    onPress: toggleIsChatOpen
  }));
};
//# sourceMappingURL=ChatComponent.js.map