import React, { useMemo, useState } from 'react';
import { Image, Text, TouchableOpacity, ActivityIndicator, StyleSheet } from 'react-native';
import { From } from '../../../../../../types/message';
import { getFileNameFromAttachment } from '../../../../../../utils/getFilenameFromAttachment';
import RNFS from 'react-native-fs';
import attachIcon from '../../../../../../assets/attach_icon.png';
const DocumentComponent = props => {
  const [isDownloading, setIsDownloading] = useState(false);
  const fileName = useMemo(() => getFileNameFromAttachment(props.message.document), [props.message.document]);
  const downloadDocumentToDevice = async () => {
    setIsDownloading(true);
    try {
      var _props$message$docume;
      const destination = `${RNFS.DownloadDirectoryPath}/${fileName}`;
      const job = RNFS.downloadFile({
        fromUrl: (_props$message$docume = props.message.document) === null || _props$message$docume === void 0 ? void 0 : _props$message$docume.fileUrl,
        toFile: destination
      });
      await job.promise;
    } catch (error) {
      throw error;
    } finally {
      setIsDownloading(false);
    }
  };
  const onDocumentPress = () => {
    downloadDocumentToDevice();
  };
  const styles = StyleSheet.create({
    bot: {
      color: props.settings.secondaryTextColor
    },
    user: {
      color: props.settings.mainTextColor
    },
    container: {
      flexDirection: 'row'
    },
    text: {
      marginLeft: 8
    }
  });
  const textColor = props.message.from === From.BOT ? styles.bot : styles.user;
  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: onDocumentPress,
    style: styles.container
  }, isDownloading ? /*#__PURE__*/React.createElement(ActivityIndicator, null) : /*#__PURE__*/React.createElement(Image, {
    source: attachIcon
  }), /*#__PURE__*/React.createElement(Text, {
    style: [styles.text, textColor]
  }, fileName));
};
export default DocumentComponent;
//# sourceMappingURL=index.js.map