import { Session } from '../entities/Session';
import { Global } from '../global';
import { channel } from '../constants';
export class SessionStorageGateway {
  constructor(storage, httpClient, ws) {
    this.storage = storage;
    this.httpClient = httpClient;
    this.ws = ws;
  }
  async sendAction(action) {
    const sessionId = await this.storage.retrieve('sessionId');
    await this.httpClient.post('/webchat/action', {
      botId: Global.botId,
      action,
      sessionId
    });
  }
  async subscribe(sessionId) {
    const response = await this.httpClient.post('/webchat/subscribe', {
      sessionId,
      botId: Global.botId,
      parameters: JSON.stringify(Global.params),
      socketId: Global.socketId,
      channel
    });
    const newSessionId = (response === null || response === void 0 ? void 0 : response.sessionId) || '';
    this.changeSession(newSessionId);
    return new Session(newSessionId);
  }
  async getCurrent() {
    const sessionId = await this.storage.retrieve('sessionId');
    if (typeof sessionId === 'string') {
      return new Session(sessionId);
    }
    return new Session('');
  }
  async changeSession(newSessionId) {
    await this.storage.store('sessionId', newSessionId);
    return newSessionId;
  }
  async clearSession() {
    const session = '';
    await this.storage.clean();
    return new Session(session);
  }
  async linkSession() {
    const sessionId = await this.storage.retrieve('sessionId');
    if (typeof sessionId === 'string') {
      this.ws.sendMessage({
        action: 'link',
        data: {
          sessionId,
          botId: Global.botId
        }
      });
    }
  }
  async onEndConversation(callback) {
    this.ws.onEndConversation(callback);
  }
}
//# sourceMappingURL=SessionStorageGateway.js.map