import { Global } from '../../global';
export class WebSocketAdapter {
  ws = null;
  onMessageCallback = null;
  onOpenCallback = null;
  onEndConversationCallback = null;
  connectionTries = 0;
  maxConnectionTries = 3;
  constructor(url, logger) {
    this.url = url;
    this.logger = logger;
  }
  connect() {
    if (this.connectionTries >= this.maxConnectionTries) {
      this.logger.log(`Maximum number of connection tries (${this.maxConnectionTries}) reached.`);
      return;
    }
    this.connectionTries++;
    this.ws = new WebSocket(this.url);
    this.ws.onopen = () => {
      this.connectionTries = 0;
      this.logger.log(`Socket connected to address: ${this.url}`);
      if (this.onOpenCallback) this.onOpenCallback();
    };
    this.ws.onclose = event => {
      this.logger.log(`Socket is closed. Reconnect will be attempted in 1 second. ${event.reason}`);
      setTimeout(() => {
        this.connect();
      }, 1000);
    };
    this.ws.onerror = err => {
      var _this$ws;
      this.logger.log(`Socket encountered error: ${JSON.stringify(err)}`);
      (_this$ws = this.ws) === null || _this$ws === void 0 ? void 0 : _this$ws.close();
    };
    this.ws.onmessage = async event => {
      var _socketAction$data2;
      const socketAction = JSON.parse(event.data);
      if (socketAction.action === 'link') {
        var _socketAction$data;
        const socketId = ((_socketAction$data = socketAction.data) === null || _socketAction$data === void 0 ? void 0 : _socketAction$data.socketId) || null;
        Global.socketId = socketId || null;
      } else if (socketAction.action === 'end_conversation' && !((_socketAction$data2 = socketAction.data) !== null && _socketAction$data2 !== void 0 && _socketAction$data2.isTransfer)) {
        if (this.onEndConversationCallback) await this.onEndConversationCallback();
      }
      if (socketAction.action === 'message' && this.onMessageCallback) {
        this.onMessageCallback(socketAction.data);
      }
    };
  }
  disconnect() {
    if (this.ws) {
      this.ws.close();
      this.ws = null;
    }
  }
  sendMessage(action) {
    if (this.ws) {
      this.ws.send(JSON.stringify(action));
    }
  }
  onMessage(callback) {
    this.onMessageCallback = callback;
  }
  onOpen(callback) {
    this.onOpenCallback = callback;
  }
  onEndConversation(callback) {
    this.onEndConversationCallback = callback;
  }
}
//# sourceMappingURL=WebSocketAdapter.js.map